@@ -24,11 +24,28 @@ class InitializationStrategy(StrategyBase, ABC):
     #  Factory Methods
     # -------------------------------------------------------------------------
     @classmethod
-    def one_shot_random(cls, constrained: bool = True, uniform: bool = False) -> Self:
-        """Create a InitOneShotRandom initialization strategy."""
-        from ._init_one_shot_random import InitOneShotRandom
+    def random_one_shot(cls, constrained: bool = True, uniform: bool = False) -> Self:
+        """Create a InitRandomOneShot initialization strategy."""
+        from ._init_random_one_shot import InitRandomOneShot
 
-        return InitOneShotRandom(
+        return InitRandomOneShot(
             constrained=constrained,
             uniform=uniform,
         )
+
+    @classmethod
+    def random_batched(cls, b: int, constrained: bool = True) -> Self:
+        """Create a InitRandomBatched initialization strategy."""
+        from ._init_random_batched import InitRandomBatched
+
+        return InitRandomBatched(
+            b=b,
+            constrained=constrained,
+        )
+
+    @classmethod
+    def eager(cls, nc: int) -> Self:
+        """Create a InitEager initialization strategy."""
+        from ._init_eager import InitEager
+
+        return InitEager(nc=nc)
